@@ -8,7 +8,7 @@ from netbox_storage.models import TemplateConfigurationDrive, Partition, Logical
 class LVMAddTemplateView(generic.ObjectEditView):
     queryset = LogicalVolume.objects.all()
     form = LVMTemplateForm
-#    default_return_url = "plugins:netbox_storage:drive_list"
+    default_return_url = "plugins:netbox_storage:drive_list"
 
 
 class AddTemplateDriveView(generic.ObjectEditView):
